@@ -191,7 +191,6 @@ END_FOR:
 	return lines;
 }
 
-
 BOOL parse_thread(nt_thread_tp threadp, const wchar_t *linep)
 {
 	wchar_t buf[1024*3+1];
@@ -241,6 +240,38 @@ BOOL parse_thread(nt_thread_tp threadp, const wchar_t *linep)
 }
 
 
+wchar_t* parse_thread_title(const wchar_t *linep)
+{
+	wchar_t buf[1024*3+1];
+	wchar_t *cptr;
+	if(!linep)
+		return FALSE;
+	int len = wcslen(linep);
+	if(len <= 0)
+		return FALSE;
+	if(len >= sizeof(buf))
+		return FALSE;
+
+	wcscpy(buf, linep);
+	cptr = wcsstr(buf, L"<>");
+	if(!cptr)
+		return FALSE;
+
+	cptr = wcsstr(cptr+2, L"<>");
+	if(!cptr)
+		return FALSE;
+
+	cptr = wcsstr(cptr+2, L"<>");
+	if(!cptr)
+		return FALSE;
+
+	cptr = wcsstr(cptr+2, L"<>");
+	if(!cptr)
+		return NULL;
+	return nt_w_str_clone(cptr + 2);
+}
+
+
 BOOL parse_board(nt_board_tp boardp, const wchar_t *linep)
 {
 	wchar_t buf[256+1];
@@ -270,7 +301,8 @@ BOOL parse_board(nt_board_tp boardp, const wchar_t *linep)
 	}else{
 		num_res = 0;
 	}
-	threadp = nt_thread_alloc(boardp, cptr1, buf, num_res);
+	threadp = nt_thread_alloc(
+			&boardp->threadlistp, cptr1, buf, num_res);
 	if(!threadp)
 		return FALSE;
 
