@@ -85,7 +85,7 @@ extern nt_category_tp nt_category_alloc(
 extern nt_board_tp nt_board_alloc( nt_category_tp categoryp, 
 		const wchar_t *name, const wchar_t *addressp);
 extern nt_thread_tp nt_thread_alloc(
-		nt_board_tp boardp, const wchar_t *name,
+		nt_link_tp *threadlistpp, const wchar_t *name,
 		const wchar_t *file_name, int num_res);
 extern nt_res_tp nt_res_alloc(nt_thread_tp	threadp, 
 		const wchar_t *name, const wchar_t *mail, 
@@ -110,4 +110,12 @@ extern void nt_set_selected_board(nt_2ch_model_tp modelp,
 		nt_category_tp categoryp, nt_board_tp boardp);
 extern void nt_set_selected_thread(nt_2ch_model_tp modelp, nt_thread_tp threadp);
 
+extern nt_thread_tp nt_get_thread_by_seq_no(
+		nt_link_tp thread_list, int seq_no);
+extern nt_thread_tp nt_get_thread_by_dat_name(
+		nt_link_tp thread_list, const wchar_t *dat_name);
+extern wchar_t* nt_read_thread_title(nt_board_tp boardp,
+		const wchar_t *dat_name);
+extern wchar_t* parse_thread_title(const wchar_t *linep);
+
 #endif /* _MODEL_2CH_H_ */
