@@ -59,12 +59,14 @@ extern char *MARU_PW;
 #define NT_COMMAND1_JMP_NEW_2 "n"
 #define NT_COMMAND1_SORT_1 "sort"
 #define NT_COMMAND1_SORT_2 "s"
-#define NT_COMMNAD1_SORT_NUMBER_1 "number"
-#define NT_COMMNAD1_SORT_NUMBER_2 "n"
-#define NT_COMMNAD1_SORT_READ_1 "read" 
-#define NT_COMMNAD1_SORT_READ_2 "r" 
-#define NT_COMMNAD1_SORT_UNREAD_1 "unread"
-#define NT_COMMNAD1_SORT_UNREAD_2 "u"
+#define NT_COMMAND1_SORT_NUMBER_1 "number"
+#define NT_COMMAND1_SORT_NUMBER_2 "n"
+#define NT_COMMAND1_SORT_READ_1 "read" 
+#define NT_COMMAND1_SORT_READ_2 "r" 
+#define NT_COMMAND1_SORT_UNREAD_1 "unread"
+#define NT_COMMAND1_SORT_UNREAD_2 "u"
+#define NT_COMMAND1_DEL_THREAD_LOG_1 "del"
+#define NT_COMMAND1_DEL_THREAD_LOG_2 "d"
 
 extern int set_option(int argc, char* argv[]);
 
