@@ -1,3 +1,20 @@
+/* Copyright 2013 Akira Ohta (akohta001@gmail.com)
+    This file is part of ntch.
+
+    The ntch is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    The ntch is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with ntch.  If not, see <http://www.gnu.org/licenses/>.
+    
+*/
 #ifndef _NT_HTTP_H_
 #define _NT_HTTP_H_
 
@@ -13,7 +30,7 @@
 
 #define HTTP_RESPONCE_HEADER_BUFFER_LEN  256
 
-#define USER_AGENT "Monazilla/1.00 (monaweb/1.00) ntch for GUN/Linux"
+#define USER_AGENT "Monazilla/1.00 (monaweb/1.00) ntch for GNU/Linux"
 
 #define CONTENT_TYPE_ZIP 1
 #define CONTENT_TYPE_TEXT 2 
