@@ -27,10 +27,14 @@
 typedef int BOOL;
 typedef void (*nt_memfree_fn)(void* ptr);
 typedef int (*nt_compare_fn)(void *lhs, void *rhs);
+typedef int (*nt_compare_n_fn)(int a, int b);
 
 typedef struct tag_nt_link_t *nt_link_tp;
 typedef struct tag_nt_link_t{
-	void * data;
+	union{
+		void * data;
+		int n_data;
+	};
 	nt_link_tp prev;
 	nt_link_tp next;
 } nt_link_t;
@@ -51,6 +55,7 @@ extern nt_stack_tp nt_stack_alloc();
 extern void nt_stack_free(nt_stack_tp ptr, nt_memfree_fn free_func);
 
 extern nt_link_tp nt_link_add_data(nt_link_tp link, void *data);
+extern nt_link_tp nt_link_add_n_data(nt_link_tp link, int  n_data);
 extern nt_link_tp nt_link_insert_before(nt_link_tp top_linkp,
 			nt_link_tp dest, nt_link_tp src);
 extern nt_link_tp nt_link_remove(nt_link_tp src, nt_link_tp target);
@@ -60,6 +65,8 @@ extern void* nt_link_get(nt_link_tp link);
 extern nt_link_tp nt_link_find(nt_link_tp link, void *data, 
 			nt_compare_fn comp_func);
 extern void nt_link_sort(nt_link_tp *linkp, nt_compare_fn comp_func);
+extern void nt_link_n_sort(nt_link_tp *linkp, 
+			nt_compare_n_fn comp_func);
 extern nt_link_tp nt_link_next(nt_link_tp link);
 extern int nt_link_num(nt_link_tp linkp);
 extern void* nt_link_get_by_index(nt_link_tp linkp, int index);
