@@ -25,10 +25,12 @@
 
 #include "env.h"
 #include "error.h"
+#include "nt_string.h"
 #include "utils/nt_std_t.h"
 #include "utils/nt_usr_db.h"
 #include "_2ch/_2ch.h"
 #include "_2ch/model_2ch.h"
+#include "_2ch/parse_2ch.h"
 #include "utils/text.h"
 #include "ui/disp.h"
 #include "ui/disp_string.h"
@@ -37,6 +39,7 @@ typedef struct tag_ctx_threadlist_t *ctx_threadlist_tp;
 typedef struct tag_ctx_threadlist_t
 {
 	int thread_num;
+	int tracked_thread_num;
 	int cursor_pos;
 	int scroll_pos;
 
@@ -57,6 +60,7 @@ typedef struct tag_ctx_threadlist_t
 #define NT_CMD_SORT_NUMBER 1
 #define NT_CMD_SORT_READ 2
 #define NT_CMD_SORT_UNREAD 3
+#define NT_CMD_DEL_THREAD_LOG 4
 
 static int parse_cmd1(const char *param);
 static int get_thread_index_by_seqno(nt_link_tp linkp, int seq_no);
@@ -65,6 +69,8 @@ static BOOL search_line_asc(regex_t *regexp,
 static BOOL search_line_desc(regex_t *regexp, 
 				nt_link_tp threadlistp, int *sel_thread_no);
 static ctx_threadlist_tp init_context(nt_2ch_model_tp modelp);
+static int merge_untracked_thread_log(nt_board_tp boardp,
+		nt_link_tp *disp_thread_listpp, nt_link_tp log_list);
 
 
 static int sort_by_number(void *lhs, void *rhs);
@@ -94,7 +100,7 @@ int disp_threadlist(nt_window_tp wp, nt_2ch_model_tp modelp,
 	ctx_threadlist_tp ctxp;
 	nt_board_tp boardp;
 	nt_thread_tp threadp;
-	nt_link_tp clistp;
+	nt_link_tp clistp, linkp;
 	int i, rows, nwrite, len, ch;
 	int btm_cur, num, wlines;
 	wchar_t buf[16];
@@ -103,6 +109,7 @@ int disp_threadlist(nt_window_tp wp, nt_2ch_model_tp modelp,
 	int read_count, column;
 	int cmd;
 	BOOL sort;
+	const char *start, *end;
 
 	sort = FALSE;
 
@@ -121,6 +128,12 @@ int disp_threadlist(nt_window_tp wp, nt_2ch_model_tp modelp,
 		ctxp->thread_data_list =
 			nt_usr_db_query_read_count_list(
 					db_handle, boardp->name);
+		if(ctxp->thread_data_list){
+			ctxp->thread_num = 
+					merge_untracked_thread_log(boardp,
+							&ctxp->thread_disp_list,
+							ctxp->thread_data_list);
+		}
 	}
 
 	if(sort){
@@ -197,6 +210,38 @@ int disp_threadlist(nt_window_tp wp, nt_2ch_model_tp modelp,
 				THREAD_SORT_TYPE = NT_THREAD_SORT_BY_UNREAD;
 				sort_thread_title(THREAD_SORT_TYPE, ctxp);
 				return DISP_STATE_REFRESH;
+			case NT_CMD_DEL_THREAD_LOG: 
+				if(!nt_strtok(wp->cmd_param,' ', &start, &end))
+					break;
+
+				if(0 == strcmp("*", end)){
+					if(!nt_usr_db_delete_board_log(db_handle,
+							boardp->name))
+						break;
+					return DISP_STATE_REFRESH;
+				}
+				linkp = parse_number_list(end, NULL);
+				if(!linkp)
+					break;
+				clistp = linkp;
+				num = -1;
+				do{
+					threadp = nt_get_thread_by_seq_no(
+						ctxp->thread_disp_list, linkp->n_data);
+					if(!threadp)
+						break;
+						
+					if(linkp->n_data != num){
+						nt_usr_db_delete_thread_log(db_handle,
+								boardp->name, 
+								threadp->file_name,
+								&ctxp->thread_data_list);
+						num = linkp->n_data;
+					}
+					linkp = linkp->next;
+				}while(clistp != linkp);
+				nt_all_link_free(linkp, NULL);
+				return DISP_STATE_REFRESH;
 			default:
 				break;
 			}
@@ -380,6 +425,7 @@ static ctx_threadlist_tp init_context(nt_2ch_model_tp modelp)
 
 	boardp = modelp->selected_boardp;
 	ctxp->thread_num = nt_link_num(boardp->threadlistp);
+	ctxp->tracked_thread_num = ctxp->thread_num;
 
 	ctxp->regex_init = FALSE;
 	ctxp->sel_thread_no = -1;
@@ -395,6 +441,34 @@ static ctx_threadlist_tp init_context(nt_2ch_model_tp modelp)
 	return ctxp;
 }
 
+int merge_untracked_thread_log(nt_board_tp boardp,
+		nt_link_tp *disp_thread_listpp, nt_link_tp log_list)
+{
+	wchar_t *title, *dat_name;
+	wchar_t buf[512];
+	nt_usr_db_thread_data_tp log_datap;
+	nt_link_tp log_linkp = log_list;
+	do{
+		log_datap =
+			(nt_usr_db_thread_data_tp)log_linkp->data;
+		dat_name = log_datap->dat_name;
+		if(nt_get_thread_by_dat_name(
+				*disp_thread_listpp, dat_name)){
+		}else if(!(title = nt_read_thread_title(
+				boardp, dat_name))){
+		}else{
+			wcscpy(buf, NT_TEXT_UNTRACKED_LOG_NAME);
+			wcscat(buf, title);
+			nt_thread_alloc(disp_thread_listpp,
+					buf, dat_name, log_datap->read_count);
+			free(title);
+		}
+		log_linkp = log_linkp->next;
+	}while(log_linkp != log_list);
+	return nt_link_num(*disp_thread_listpp);
+}
+
+
 void init_threadlist_ctx(void *ptr)
 {
 	ctx_threadlist_tp ctxp;
@@ -410,6 +484,11 @@ void init_threadlist_ctx(void *ptr)
 
 void free_threadlist_ctx(void *ptr)
 {
+	nt_link_tp linkp, nextp;
+	nt_thread_tp threadp;
+	int num;
+	wchar_t *cptr;
+
 	ctx_threadlist_tp ctxp;
 	if(!ptr)
 		return;
@@ -419,7 +498,26 @@ void free_threadlist_ctx(void *ptr)
 			nt_usr_db_thread_data_free);
 	}
 	if(ctxp->thread_disp_list){
-		nt_all_link_free(ctxp->thread_disp_list, NULL);
+		linkp = ctxp->thread_disp_list->next;
+		num = 1;
+		while(linkp != ctxp->thread_disp_list){
+			nextp = linkp->next;
+			if(ctxp->tracked_thread_num <= num){
+				threadp = linkp->data;
+				cptr = wcsstr(threadp->name, 
+						NT_TEXT_UNTRACKED_LOG_NAME);
+				if(cptr){
+					nt_thread_free(threadp);
+				}
+			}
+			free(linkp);
+			num++;
+			linkp = nextp;
+		}
+		free(linkp);
+	}
+	if(ctxp->regex_init){
+		regfree(&(ctxp->regex));
 	}
 	free(ctxp);
 }
@@ -555,6 +653,11 @@ static int parse_cmd1(const char *param)
 	}else if( 0 == strncmp(NT_COMMAND1_SORT_2, param,
 			strlen(NT_COMMAND1_SORT_2))){
 		offset = strlen(NT_COMMAND1_SORT_2);
+	}else if(0 == strncmp(NT_COMMAND1_DEL_THREAD_LOG_1,param,
+			strlen(NT_COMMAND1_DEL_THREAD_LOG_1)) ||
+		0 == strncmp(NT_COMMAND1_DEL_THREAD_LOG_2,param,
+			strlen(NT_COMMAND1_DEL_THREAD_LOG_2))){
+		return NT_CMD_DEL_THREAD_LOG;
 	}else{
 		return NT_CMD_NONE;
 	}
@@ -565,14 +668,14 @@ static int parse_cmd1(const char *param)
 	if(len <= 0)
 		return NT_CMD_ERR;
 
-	if(0 == strncmp(start, NT_COMMNAD1_SORT_NUMBER_1,len) ||
-		0 == strncmp(start, NT_COMMNAD1_SORT_NUMBER_2,len)){
+	if(0 == strncmp(start, NT_COMMAND1_SORT_NUMBER_1,len) ||
+		0 == strncmp(start, NT_COMMAND1_SORT_NUMBER_2,len)){
 		return NT_CMD_SORT_NUMBER;
-	}else if(0 == strncmp(start, NT_COMMNAD1_SORT_READ_1,len) ||
-		0 == strncmp(start, NT_COMMNAD1_SORT_READ_2,len)){
+	}else if(0 == strncmp(start, NT_COMMAND1_SORT_READ_1,len) ||
+		0 == strncmp(start, NT_COMMAND1_SORT_READ_2,len)){
 		return NT_CMD_SORT_READ;
-	}else if(0 == strncmp(start, NT_COMMNAD1_SORT_UNREAD_1,len) ||
-		0 == strncmp(start, NT_COMMNAD1_SORT_UNREAD_2,len)){
+	}else if(0 == strncmp(start, NT_COMMAND1_SORT_UNREAD_1,len) ||
+		0 == strncmp(start, NT_COMMAND1_SORT_UNREAD_2,len)){
 		return NT_CMD_SORT_UNREAD;
 	}
 	return NT_CMD_ERR;
@@ -603,6 +706,14 @@ static int sort_by_unread(void *lhs, void *rhs)
 	nt_thread_tp lthread, rthread;
 	lthread = (nt_thread_tp)lhs;
 	rthread = (nt_thread_tp)rhs;
+
+	if(lthread->seq_no > g_ctxp->tracked_thread_num &&
+		rthread->seq_no <= g_ctxp->tracked_thread_num){
+		return -1;
+	}else if(rthread->seq_no > g_ctxp->tracked_thread_num &&
+		lthread->seq_no <= g_ctxp->tracked_thread_num){
+		return 1;
+	}
 	num1 = nt_usr_db_get_read_count_by_dat_name(
 		g_ctxp->thread_data_list, lthread->file_name);
 	num2 = nt_usr_db_get_read_count_by_dat_name(
@@ -625,6 +736,13 @@ static int sort_by_read(void *lhs, void *rhs)
 	nt_thread_tp lthread, rthread;
 	lthread = (nt_thread_tp)lhs;
 	rthread = (nt_thread_tp)rhs;
+	if(lthread->seq_no > g_ctxp->tracked_thread_num &&
+		rthread->seq_no <= g_ctxp->tracked_thread_num){
+		return -1;
+	}else if(rthread->seq_no > g_ctxp->tracked_thread_num &&
+		lthread->seq_no <= g_ctxp->tracked_thread_num){
+		return 1;
+	}
 	num1 = nt_usr_db_get_read_count_by_dat_name(
 		g_ctxp->thread_data_list, lthread->file_name);
 	num2 = nt_usr_db_get_read_count_by_dat_name(
