@@ -63,6 +63,29 @@ void nt_link_sort(nt_link_tp *top_linkp, nt_compare_fn comp_func)
 
 }
 
+void nt_link_n_sort(nt_link_tp *top_linkp, nt_compare_n_fn comp_func)
+{
+	nt_link_tp cur_linkp, next_linkp, work_linkp;
+
+	cur_linkp = *top_linkp;
+	do{
+		next_linkp = cur_linkp->next;
+		work_linkp = *top_linkp;
+
+		while(work_linkp != cur_linkp){
+			if(0 < (comp_func)(cur_linkp->n_data, work_linkp->n_data)){
+				*top_linkp = nt_link_remove2(*top_linkp, cur_linkp);
+				*top_linkp = nt_link_insert_before(
+						*top_linkp, work_linkp, cur_linkp);
+				break;
+			}
+			work_linkp = work_linkp->next;
+		}
+		cur_linkp = next_linkp;
+	}while(cur_linkp != *top_linkp);
+
+}
+
 int nt_link_num(nt_link_tp linkp){
 	nt_link_tp curp;
 	int num = 1;
@@ -113,6 +136,26 @@ nt_link_tp nt_link_add_data(nt_link_tp link, void *data)
 	return ptr;
 }
 
+nt_link_tp nt_link_add_n_data(nt_link_tp link, int n_data)
+{
+	nt_link_tp ptr = calloc(1,sizeof(nt_link_t));
+	if(ptr == NULL)
+		return NULL;
+
+	ptr->n_data = n_data;
+	
+	if(link != NULL){
+		ptr->prev = link->prev;
+		ptr->prev->next = ptr;
+		link->prev = ptr;
+		ptr->next = link;
+	}else{
+		ptr->prev = ptr;
+		ptr->next = ptr;
+	}
+	return ptr;
+}
+
 nt_link_tp nt_link_remove(nt_link_tp src, nt_link_tp target)
 {
 	while(src != target){
